@@ -702,7 +702,7 @@ static int my_res_init()
 #endif
 
 #if defined(JDNS_OS_MAC) || defined(JDNS_OS_FREEBSD) || \
-defined(JDNS_OS_NETBSD) || defined (JDNS_OS_SOLARIS)
+defined(JDNS_OS_NETBSD) || defined(JDNS_OS_OPENBSD) || defined (JDNS_OS_SOLARIS)
 # define USE_EXTEXT
 #endif
 
@@ -719,6 +719,12 @@ static jdns_dnsparams_t *dnsparams_get_unixsys()
 #else
 	n = my_res_init();
 #define RESVAR _res
+#endif
+
+#ifdef JDNS_OS_OPENBSD
+#define RESVAREXT _res_ext
+#else
+#define RESVAREXT RESVAR._u._ext
 #endif
 
 	params = jdns_dnsparams_new();
@@ -728,15 +734,21 @@ static jdns_dnsparams_t *dnsparams_get_unixsys()
 		return params;
 
 	/* nameservers - ipv6 */
-	for(n = 0; n < MAXNS && n < RESVAR._u._ext.nscount; ++n)
+#ifdef JDNS_OS_OPENBSD
+	for(n = 0; n < MAXNS; ++n)
+#else
+	for(n = 0; n < MAXNS && n < RESVAREXT.nscount; ++n)
+#endif
 	{
 		jdns_address_t *addr;
 		struct sockaddr_in6 *sa6;
 
-#ifdef USE_EXTEXT
-		sa6 = ((struct sockaddr_in6 *)RESVAR._u._ext.ext) + n;
+#if defined(USE_EXTEXT) && !defined(JDNS_OS_OPENBSD)
+		sa6 = ((struct sockaddr_in6 *)RESVAREXT.ext) + n;
+#elif defined(JDNS_OS_OPENBSD)
+		sa6 = &RESVAREXT.nsaddr_list[n];
 #else
-		sa6 = RESVAR._u._ext.nsaddrs[n];
+		sa6 = RESVAREXT.nsaddrs[n];
 #endif
 
 		if(sa6 == NULL)
